/*
  Copyright 1999 Brian H. Trammell (brian@altara.org)
  Copyright 1999 Ben Parrott (benji@altara.org)
  
  This software (and its source code) are freely usable, modifiable, 
  and redistributable under the terms of the GNU General Public License, 
  available at http://www.gnu.org/copyleft/gpl.html, and in the ./COPYING 
  file in the MARS distribution.
*/

package org.altara.mars;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.util.*;

/**
 *  This class allows for buttons to be inputed into a toolbar
 *  by creating an Action for the button
 *
 */

// Revision 1.3.0: 06 Apr 1999 bht - changed class name to MARSAction,
//                                   because it's used in menus, too.
//                                   Put action text in constants.
// Revision 1.3.2: 12 Apr 1999 bht - Added MoveUp/MoveDown actions.
// Revision 1.4.1: 29 Apr 1999 bht - Added Mail Notification options.
// Revision 1.4.6: 16 May 1999 bht - Fixed MainUI method names.

public class MARSAction extends AbstractAction
{

    /** Text of the Add Host action */
    public static final String ADD = "Add Host...";
    /** Text of the Delete Host action */
    public static final String DELETE = "Delete Host";
    /** Text of the Set Visible Name action */
    public static final String SETVIS = "Set Visible Name...";
    /** Text of the Set DNS Name action */
    public static final String SETDNS = "Set FQDN...";
    /** Text of the Move Host Up action */
    public static final String MOVEUP = "Move Up List";
    /** Text of the Move Host Down action */
    public static final String MOVEDOWN = "Move Down List";
    /** Text of the Adjust Update Interval action */
    public static final String UPDATE = "Update Interval...";
    /** Text of the Adjust Timeout action */
    public static final String TIMEOUT = "Timeout...";
    /** Text of the Adjust Load Threshold action */
    public static final String MAXLOAD = "Max Load Threshold...";
    /** Text of the Adjust Disk Threshold action */
    public static final String MINDISK = "Min Disk Threshold...";
    /** Text of the Configure Mail Notification item */
    public static final String CFGMAIL = "Set up mail notification...";
    /** Text of the Configure Mail Notification item */
    public static final String DISMAIL = "Disable mail notification";   
    /** Text of the Save action */
    public static final String SAVE = "Save";
    /** Text of the Cancel action */
    public static final String CANCEL = "Cancel";
    /** Text of the Stop action */
    public static final String STOP = "Stop";
    /** Text of the Start action */
    public static final String START = "Start";
    /** Text of the Configure action */
    public static final String CONFIGURE = "Configure";
    /** Text of the Quit action */
    public static final String QUIT = "Exit";

/**
 *  Allows the creation of a MARSAction with only a text label
 */
public MARSAction(String text)
{
 super(text);
}

/**
 *  Allows the creation of a MARSAction with a text label
 *  and a graphical icon
 */
public MARSAction(String text, Icon icon)
{
 super(text, icon);
}

public void actionPerformed(ActionEvent e)
{
  /* This is a poor mans case statement, that checks the ActionCommand
     to see what button was pressed and reacts accordingly */

  if (e.getActionCommand() == ADD)
      MARSConfigUI.getCurrent().addPressed();
  else if (e.getActionCommand() == DELETE)
    MARSConfigUI.getCurrent().deletePressed();
  else if (e.getActionCommand() == SETVIS)
      MARSConfigUI.getCurrent().setVisibleNamePressed();
  else if (e.getActionCommand() == SETDNS)
      MARSConfigUI.getCurrent().setDnsNamePressed();  
  else if (e.getActionCommand() == MOVEUP)
    MARSConfigUI.getCurrent().moveUpPressed();
  else if (e.getActionCommand() == MOVEDOWN)
    MARSConfigUI.getCurrent().moveDownPressed();
  else if (e.getActionCommand() == UPDATE)
    MARSConfigUI.getCurrent().adjustUpdateIntervalPressed();
  else if (e.getActionCommand() == TIMEOUT)
    MARSConfigUI.getCurrent().adjustTimeOutPressed();
  else if (e.getActionCommand() == MAXLOAD)
    MARSConfigUI.getCurrent().adjustLoadPressed();
  else if (e.getActionCommand() == MINDISK)
    MARSConfigUI.getCurrent().adjustDiskPressed();
  else if (e.getActionCommand() == SAVE)
    MARSConfigUI.getCurrent().savePressed();
  else if (e.getActionCommand() == CANCEL)
    MARSConfigUI.getCurrent().cancelPressed();
  else if (e.getActionCommand() == CFGMAIL)
    MARSConfigUI.getCurrent().configMailSelected();
  else if (e.getActionCommand() == DISMAIL)
    MARSConfigUI.getCurrent().disableMailSelected();  
  else if (e.getActionCommand() == STOP)
    MARSMainUI.getCurrent().stopSelected();
  else if (e.getActionCommand() == START)
    MARSMainUI.getCurrent().startSelected();
  else if (e.getActionCommand() == CONFIGURE)
    MARSMainUI.getCurrent().configSelected();
  else if (e.getActionCommand() == QUIT)
    MARSMainUI.getCurrent().quitSelected();

}

}


